#
# spec file for package e-antic
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%define lname	libeantic3
Name:           e-antic
Version:        2.0.2
Release:        1.4
Summary:        Real Embedded Algebraic Number Theory in C
License:        LGPL-2.1-or-later AND LGPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://github.com/flatsurf/e-antic

Source:         https://github.com/flatsurf/e-antic/releases/download/%version/e-antic-%version.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  automake
BuildRequires:  cereal-devel
BuildRequires:  fdupes
BuildRequires:  flint-devel >= 3
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
BuildRequires:  libboost_headers-devel
BuildRequires:  libtool
BuildRequires:  python-rpm-macros
BuildRequires:  unique-factory-devel
BuildRequires:  pkgconfig(catch2)
Obsoletes:      python-pyeantic < %version-%release
Provides:       python-pyeantic = %version-%release
%python_subpackages

%description
E-ANTIC is a C/C++ library to deal with real embedded number fields
built on top of ANTIC.

%package -n %lname
Summary:        Real Embedded Algebraic Number Theory library in C
Group:          System/Libraries

%description -n %lname
E-ANTIC is a C/C++ library to deal with real embedded number fields
built on top of ANTIC.

%package devel
Summary:        Development files for e-antic
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       flint-devel
Requires:       libboost_headers-devel

%description devel
E-ANTIC is a C/C++ library to deal with real embedded number fields
built on top of ANTIC.

This subpackage contains the include files and library links for
developing against the ANTIC library.

%prep
%autosetup -p1

%build
autoreconf -fi
%define _configure ../configure
%{python_expand #
mkdir p%{$python_bin_suffix}/
pushd p%{$python_bin_suffix}/
%configure --disable-static --without-benchmark --without-byexample \
	--without-pytest --without-doc PYTHON="python%{$python_bin_suffix}" \
	CPPFLAGS="-I/usr/include/flint"
%make_build
popd
}

%install
%{python_expand #
pushd p%{$python_bin_suffix}/
%make_install
popd
}
rm -f "%buildroot/%_libdir"/*.la
find "%buildroot" -name install_files.txt -delete
%fdupes %buildroot/%_prefix

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license COPY*
%_libdir/libeantic*.so.[0-9]*

%files -n %name-devel
%_includedir/e-antic/
%_includedir/libeantic/
%_libdir/libeantic*.so

%files %python_files
%python_sitelib/pyeantic*/

%changelog
* Thu Jan 11 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.0.2
  * Fixed an exception being thrown when run under PyPy
    (github.com/wlav/cppyy/issues/209)
* Tue Jan  9 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.0.1
  * Fixed segfault when using non-intrusive pointers to renf_class
    such as the ones returned by parent() from Python.
* Thu Dec 14 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.0.0
  * Added support for FLINT 3
- Drop flint3.diff (obsolete)
* Sun Oct 22 2023 Jan Engelhardt <jengelh@inai.de>
- Add flint3.diff to have the build succeed with flint-3.
* Tue Dec  6 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.0
  * Added support for FLINT 2.8 and 2.9
  * Added short and unsigned short operators to C++ interface.
* Tue Oct 25 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.3
  * Library version bump was missing
* Tue Oct 25 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.2
  * Fixed conda channels used for binder notebooks.
  * Fixed deserialization of renf_class from old Python pickles.
  * Fixed serialization with cereal 1.3.1+.
* Fri May 20 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.1
  * Fixed serialization of renf_class with cereal>=1.3.2
  * Fixed deserialization of objects serialized with e-antic
    prior to 1.0.0
* Sun Apr 10 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.0
  * Improved conversion from vectors of rational coefficients to
    renf_elem_class by using a faster code path in FLINT.
  * Improved conversion from SageMath number fields to pyeantic
    RealEmbeddedNumberField. This adds a dependency of pyeantic
    on gmpxxyy.
* Thu Feb 10 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.1.0
  * Added support for Python 3.10; dropped explicit support for
    Python 3.6.
  * Header file e-antic.h is now called local.h. There is still a
    header file e-antic.h that includes all of e-antic's C
    interface, so in particular local.h.
  * Header file renfxx_fwd.hpp is now called forward.hpp. The old
    header file renfxx_fwd.hpp can still be used.
  * Header file renfxx.h is now called e-antic.hpp. The old
    header file renfxx.h can still be used.
* Sun Aug 15 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.0.3
  * Fixed linking of C++ test programs.
* Fri Aug  6 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.0.2
  * Fixed parsing of trivial number fields in pyeantic.
  * Conversion from NumberField to RealEmbeddedNumberField when
    the defining polynomial is not in x.
* Fri Jul  2 2021 Jan Engelhardt <jengelh@inai.de>
- Add Requires to e-antic-devel so that all headers can be used.
* Fri Jun 25 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.0.1
  * Allow creation of RealEmbeddedNumberField from an intrusive
    pointer in pyeantic.
* Fri Jun 18 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.0.0
  * Added Python wrapper
  * Added renf_elem_class::floordiv() to perform (a/b).floor()
    more efficiently
  * The C++ interface now requires C++14.
* Tue Sep 22 2020 Jan Engelhardt <jengelh@inai.de>
- Initial package (version 1.0.0~rc1) for build.opensuse.org
